marktools.get_lilypond_comment_attached_to_component
====================================================

.. autofunction:: abjad.tools.marktools.get_lilypond_comment_attached_to_component.get_lilypond_comment_attached_to_component
